@@ -21,10 +21,6 @@ __author__ = 'Victor Olaya'
 __date__ = 'August 2012'
 __copyright__ = '(C) 2012, Victor Olaya'
 
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
-
 import os
 import re
 
@@ -37,11 +33,11 @@ from qgis.core import (QgsMapLayer,
                        QgsProcessingParameterMultipleLayers,
                        QgsProcessingParameterBoolean,
                        QgsProcessingParameterEnum,
+                       QgsProject,
                        QgsProcessingParameterMatrix)
 from qgis.PyQt.QtWidgets import QWidget, QPushButton, QLineEdit, QHBoxLayout, QSizePolicy, QFileDialog
 
 from processing.gui.AutofillDialog import AutofillDialog
-from processing.gui.ParameterGuiUtils import getFileFilter
 
 
 class BatchOutputSelectionPanel(QWidget):
@@ -74,7 +70,7 @@ class BatchOutputSelectionPanel(QWidget):
             self.selectDirectory()
             return
 
-        filefilter = getFileFilter(self.output)
+        filefilter = self.output.createFileFilter()
         settings = QgsSettings()
         if settings.contains('/Processing/LastBatchOutputPath'):
             path = str(settings.value('/Processing/LastBatchOutputPath'))
@@ -92,47 +88,50 @@ class BatchOutputSelectionPanel(QWidget):
             dlg = AutofillDialog(self.alg)
             dlg.exec_()
             if dlg.mode is not None:
-                try:
-                    if dlg.mode == AutofillDialog.DO_NOT_AUTOFILL:
-                        self.table.cellWidget(self.row,
-                                              self.col).setValue(filename)
-                    elif dlg.mode == AutofillDialog.FILL_WITH_NUMBERS:
-                        n = self.table.rowCount() - self.row
-                        for i in range(n):
-                            name = filename[:filename.rfind('.')] \
-                                + str(i + 1) + filename[filename.rfind('.'):]
-                            self.table.cellWidget(i + self.row,
-                                                  self.col).setValue(name)
-                    elif dlg.mode == AutofillDialog.FILL_WITH_PARAMETER:
-                        n = self.table.rowCount() - self.row
-                        for i in range(n):
-                            widget = self.table.cellWidget(i + self.row,
-                                                           dlg.param_index)
-                            param = self.alg.parameterDefinitions()[dlg.param_index]
-                            if isinstance(param, (QgsProcessingParameterRasterLayer,
-                                                  QgsProcessingParameterFeatureSource,
-                                                  QgsProcessingParameterVectorLayer,
-                                                  QgsProcessingParameterMultipleLayers)):
-                                v = widget.value()
-                                if isinstance(v, QgsMapLayer):
-                                    s = v.name()
+                if dlg.mode == AutofillDialog.DO_NOT_AUTOFILL:
+                    self.table.cellWidget(self.row,
+                                          self.col).setValue(filename)
+                elif dlg.mode == AutofillDialog.FILL_WITH_NUMBERS:
+                    n = self.table.rowCount() - self.row
+                    for i in range(n):
+                        name = filename[:filename.rfind('.')] \
+                            + str(i + 1) + filename[filename.rfind('.'):]
+                        self.table.cellWidget(i + self.row,
+                                              self.col).setValue(name)
+                elif dlg.mode == AutofillDialog.FILL_WITH_PARAMETER:
+                    for row in range(self.row, self.table.rowCount()):
+                        v = self.panel.valueForParameter(row - 1, dlg.param_name)
+                        param = self.alg.parameterDefinition(dlg.param_name)
+                        if isinstance(param, (QgsProcessingParameterRasterLayer,
+                                              QgsProcessingParameterFeatureSource,
+                                              QgsProcessingParameterVectorLayer,
+                                              QgsProcessingParameterMultipleLayers)):
+                            if isinstance(v, QgsMapLayer):
+                                s = v.name()
+                            else:
+                                if v in QgsProject.instance().mapLayers():
+                                    layer = QgsProject.instance().mapLayer(v)
+                                    # value is a layer ID, but we'd prefer to show a layer name if it's unique in the project
+                                    if len([l for _, l in QgsProject.instance().mapLayers().items() if l.name().lower() == layer.name().lower()]) == 1:
+                                        s = layer.name()
+                                    else:
+                                        # otherwise fall back to layer id
+                                        s = v
                                 else:
+                                    # else try to use file base name
+                                    # TODO: this is bad for database sources!!
                                     s = os.path.basename(v)
                                     s = os.path.splitext(s)[0]
-                            elif isinstance(param, QgsProcessingParameterBoolean):
-                                s = str(widget.currentIndex() == 0)
-                            elif isinstance(param, QgsProcessingParameterEnum):
-                                s = str(widget.currentText())
-                            elif isinstance(param, QgsProcessingParameterMatrix):
-                                s = str(widget.table)
-                            else:
-                                s = str(widget.text())
-                            name = filename[:filename.rfind('.')] + s \
-                                + filename[filename.rfind('.'):]
-                            self.table.cellWidget(i + self.row,
-                                                  self.col).setValue(name)
-                except:
-                    pass
+                        elif isinstance(param, QgsProcessingParameterBoolean):
+                            s = 'true' if v else 'false'
+                        elif isinstance(param, QgsProcessingParameterEnum):
+                            s = param.options()[v]
+                        else:
+                            s = str(v)
+                        name = filename[:filename.rfind('.')] + s \
+                            + filename[filename.rfind('.'):]
+                        self.table.cellWidget(row,
+                                              self.col).setValue(name)
 
     def selectDirectory(self):
 
